==> sqflite_sqlcipher-1.1.4.tar.gz: example/lib/todo_test_page.dart <==
import 'dart:async';

import 'package:sqflite_sqlcipher/sqflite.dart';

import 'test_page.dart';

/// `todo` table name
final String tableTodo = 'todo';

/// id column name
final String columnId = '_id';

/// title column name
final String columnTitle = 'title';

/// done column name
final String columnDone = 'done';

/// Todo model.
class Todo {
  /// Todo model.
  Todo();

  /// Read from a record.
  Todo.fromMap(Map map) {
    id = map[columnId] as int;
    title = map[columnTitle] as String;
    done = map[columnDone] == 1;
  }

  /// id.
  int id;

  /// title.
  String title;

  /// done.
  bool done;

  /// Convert to a record.
  Map<String, dynamic> toMap() {
    var map = <String, dynamic>{
      columnTitle: title,
      columnDone: done == true ? 1 : 0
    };
    if (id != null) {
      map[columnId] = id;
    }
    return map;
  }
}

/// Todo provider.
class TodoProvider {
  /// The database when opened.
  Database db;

  /// Open the database.
  Future open(String path) async {
    db = await openDatabase(path, version: 1,
        onCreate: (Database db, int version) async {
      await db.execute('''
create table $tableTodo ( 
  $columnId integer primary key autoincrement, 
  $columnTitle text not null,
  $columnDone integer not null)
''');
    });
  }

  /// Insert a todo.
  Future<Todo> insert(Todo todo) async {
    todo.id = await db.insert(tableTodo, todo.toMap());
    return todo;
  }

  /// Get a todo.
  Future<Todo> getTodo(int id) async {
    List<Map> maps = await db.query(tableTodo,
        columns: [columnId, columnDone, columnTitle],
        where: '$columnId = ?',
        whereArgs: [id]);
    if (maps.isNotEmpty) {
      return Todo.fromMap(maps.first);
    }
    return null;
  }

  /// Delete a todo.
  Future<int> delete(int id) async {
    return await db.delete(tableTodo, where: '$columnId = ?', whereArgs: [id]);
  }

  /// Update a todo.
  Future<int> update(Todo todo) async {
    return await db.update(tableTodo, todo.toMap(),
        where: '$columnId = ?', whereArgs: [todo.id]);
  }

  /// Close database.
  Future close() async => db.close();
}

/// Todo test page.
class TodoTestPage extends TestPage {
  /// Todo test page.
  TodoTestPage() : super('Todo example') {
    test('open', () async {
      // await Sqflite.devSetDebugModeOn(true);
      var path = await initDeleteDb('simple_todo_open.db');
      var todoProvider = TodoProvider();
      await todoProvider.open(path);

      await todoProvider.close();
      //await Sqflite.setDebugModeOn(false);
    });

    test('insert/query/update/delete', () async {
      // await Sqflite.devSetDebugModeOn();
      var path = await initDeleteDb('simple_todo.db');
      var todoProvider = TodoProvider();
      await todoProvider.open(path);

      var todo = Todo()..title = 'test';
      await todoProvider.insert(todo);
      expect(todo.id, 1);

      expect(await todoProvider.getTodo(0), null);
      todo = await todoProvider.getTodo(1);
      expect(todo.id, 1);
      expect(todo.title, 'test');
      expect(todo.done, false);

      todo.done = true;
      expect(await todoProvider.update(todo), 1);
      todo = await todoProvider.getTodo(1);
      expect(todo.id, 1);
      expect(todo.title, 'test');
      expect(todo.done, true);

      expect(await todoProvider.delete(0), 0);
      expect(await todoProvider.delete(1), 1);
      expect(await todoProvider.getTodo(1), null);

      await todoProvider.close();
      //await Sqflite.setDebugModeOn(false);
    });
  }
}

==> sqflite_sqlcipher-2.1.1.tar.gz: example/lib/todo_test_page.dart <==
import 'dart:async';

import 'package:sqflite_sqlcipher/sqflite.dart';

import 'test_page.dart';

/// `todo` table name
final String tableTodo = 'todo';

/// id column name
final String columnId = '_id';

/// title column name
final String columnTitle = 'title';

/// done column name
final String columnDone = 'done';

/// Todo model.
class Todo {
  /// Todo model.
  Todo();

  /// Read from a record.
  Todo.fromMap(Map map) {
    id = map[columnId] as int?;
    title = map[columnTitle] as String?;
    done = map[columnDone] == 1;
  }

  /// id.
  int? id;

  /// title.
  String? title;

  /// done.
  bool? done;

  /// Convert to a record.
  Map<String, dynamic> toMap() {
    var map = <String, dynamic>{
      columnTitle: title,
      columnDone: done == true ? 1 : 0
    };
    if (id != null) {
      map[columnId] = id;
    }
    return map;
  }
}

/// Todo provider.
class TodoProvider {
  /// The database when opened.
  late Database db;

  /// Open the database.
  Future open(String path) async {
    db = await openDatabase(path, version: 1,
        onCreate: (Database db, int version) async {
      await db.execute('''
create table $tableTodo ( 
  $columnId integer primary key autoincrement, 
  $columnTitle text not null,
  $columnDone integer not null)
''');
    });
  }

  /// Insert a todo.
  Future<Todo> insert(Todo todo) async {
    todo.id = await db.insert(tableTodo, todo.toMap());
    return todo;
  }

  /// Get a todo.
  Future<Todo?> getTodo(int id) async {
    List<Map> maps = await db.query(tableTodo,
        columns: [columnId, columnDone, columnTitle],
        where: '$columnId = ?',
        whereArgs: [id]);
    if (maps.isNotEmpty) {
      return Todo.fromMap(maps.first);
    }
    return null;
  }

  /// Delete a todo.
  Future<int> delete(int id) async {
    return await db.delete(tableTodo, where: '$columnId = ?', whereArgs: [id]);
  }

  /// Update a todo.
  Future<int> update(Todo todo) async {
    return await db.update(tableTodo, todo.toMap(),
        where: '$columnId = ?', whereArgs: [todo.id!]);
  }

  /// Close database.
  Future close() async => db.close();
}

/// Todo test page.
class TodoTestPage extends TestPage {
  /// Todo test page.
  TodoTestPage() : super('Todo example') {
    test('open', () async {
      // await Sqflite.devSetDebugModeOn(true);
      var path = await initDeleteDb('simple_todo_open.db');
      var todoProvider = TodoProvider();
      await todoProvider.open(path);

      await todoProvider.close();
      //await Sqflite.setDebugModeOn(false);
    });

    test('insert/query/update/delete', () async {
      // await Sqflite.devSetDebugModeOn();
      var path = await initDeleteDb('simple_todo.db');
      var todoProvider = TodoProvider();
      await todoProvider.open(path);

      var todo = Todo()..title = 'test';
      await todoProvider.insert(todo);
      expect(todo.id, 1);

      expect(await todoProvider.getTodo(0), null);
      todo = (await todoProvider.getTodo(1))!;
      expect(todo.id, 1);
      expect(todo.title, 'test');
      expect(todo.done, false);

      todo.done = true;
      expect(await todoProvider.update(todo), 1);
      todo = (await todoProvider.getTodo(1))!;
      expect(todo.id, 1);
      expect(todo.title, 'test');
      expect(todo.done, true);

      expect(await todoProvider.delete(0), 0);
      expect(await todoProvider.delete(1), 1);
      expect(await todoProvider.getTodo(1), null);

      await todoProvider.close();
      //await Sqflite.setDebugModeOn(false);
    });
  }
}
